local _, dc = ...

dc.addonPrefix = "DCOribos"
dc.askMessage = "ASK"
DCovenant = {
    ["iconSize"] = 16,
}
DCovenantLog = true

local isAsked = false

local playerName = UnitName("player")
local realmName = ""

local frame = CreateFrame("FRAME", "DetailsCovenantFrame");
frame:RegisterEvent("PLAYER_ENTERING_WORLD");


local function init()
    local _, playerClass = UnitClass("player")
    realmName = GetNormalizedRealmName()
    dc.oribos:addCovenantForPlayer(C_Covenants.GetActiveCovenantID(), UnitName("player"), playerClass)

    frame:RegisterEvent("GROUP_ROSTER_UPDATE");
    frame:RegisterEvent("CHAT_MSG_ADDON")
    C_ChatInfo.RegisterAddonMessagePrefix(dc.addonPrefix)
    frame:RegisterEvent("COMBAT_LOG_EVENT_UNFILTERED");
end

local function eventHandler(self, event, ...)
    if event == "COMBAT_LOG_EVENT_UNFILTERED" then
        local _, subevent, _, sourceGUID, sourceName = CombatLogGetCurrentEventInfo()

        if subevent == "SPELL_CAST_SUCCESS" then
            local _, englishClass = GetPlayerInfoByGUID(sourceGUID)
            local classAbilityMap = dc.spellMaps.abilityMap[englishClass]

            if classAbilityMap then
                local spellID = select(12, CombatLogGetCurrentEventInfo())
                local covenantIDByAbility = classAbilityMap[spellID]
                local covenantIDByUtility = dc.spellMaps.utilityMap[spellID]

                dc.oribos:logNewPlayer(covenantIDByAbility, sourceName, englishClass, spellID)
                dc.oribos:addCovenantForPlayer(covenantIDByAbility, sourceName, englishClass)

                dc.oribos:logNewPlayer(covenantIDByUtility, sourceName, englishClass, spellID)
                dc.oribos:addCovenantForPlayer(covenantIDByUtility, sourceName, englishClass)
            end
        end
    elseif event == "GROUP_ROSTER_UPDATE" then
        dc.oribos:fillCovenants()
    elseif event == "CHAT_MSG_ADDON" then
        local prefix, messageText, _, sender = ...

        if prefix == dc.addonPrefix then
            if string.match(messageText, dc.askMessage) then
                local _, askForName = dc.utils:splitMessage(messageText)

                if string.match(askForName, playerName) then 
                    dc.oribos:sendCovenantInfo(playerName)
                end 
            elseif dc.oribos:hasPlayerWithEmptyCovenant() then
                local senderName, senderRealm = dc.utils:splitName(sender)
                if senderName ~= playerName then
                    local name, covenantID, playerClass = dc.utils:splitMessage(messageText)

                    if realmName ~= senderRealm then
                        name = name.."-"..senderRealm
                    end

                    dc.oribos:logNewPlayer(tonumber(covenantID), name, playerClass)
                    dc.oribos:addCovenantForPlayer(tonumber(covenantID), name, playerClass)
                end
            end
        end
    elseif event == "PLAYER_ENTERING_WORLD" then
        init()
        dc:replaceDetailsImplmentation()
        dc:replaceSkadaImplmentation()
        frame:UnregisterEvent("PLAYER_ENTERING_WORLD");
    end
end

frame:SetScript("OnEvent", eventHandler);
